@@ -40,7 +40,7 @@ import org.mozilla.jss.crypto.*;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.InitializationValues;
 
-import sun.security.pkcs11.wrapper.PKCS11Constants;
+import org.mozilla.jss.pkcs11.PKCS11Constants;
 import java.nio.ByteBuffer;
 import java.util.Arrays;
 import java.util.Enumeration;
